.. _chordal:

Chordal
=======

.. toctree::
   :maxdepth: 2

.. automodule:: networkx.algorithms.chordal.chordal_alg
.. autosummary::
   :toctree: generated/

   is_chordal
   chordal_graph_cliques
   chordal_graph_treewidth
   find_induced_nodes

